@@ -14,8 +14,8 @@ sub write_out {
     my $query = $feed->{'query'};
     my $hash = $feed->{'feed'};
     my $group_map = ($config->{'group_map'}) ? $hash->{'group_map'} : undef;
-
-    my @config_search_path = ( $feed->{'query'}, 'client' );
+    
+    my @config_search_path = ('claoverride',  $feed->{'query'}, 'client' );
 
     # fields class evenrowclass oddrowclass display
     
@@ -24,7 +24,7 @@ sub write_out {
     my $cfg_class = confor($config, \@config_search_path, 'class', undef);
     my $cfg_evenrowclass = confor($config, \@config_search_path, 'evenrowclass', undef);
     my $cfg_oddrowclass = confor($config, \@config_search_path, 'oddrowclass', undef);
-    
+
     my $created = $hash->{'created'} || $hash->{'detecttime'};
     my $feedid = $hash->{'id'};
     my @a = @{$hash->{'entry'}};
@@ -82,13 +82,13 @@ sub write_out {
             'alternativeid_restriction',
             'alternativeid',
         ));
-   }
-   if($cfg_fields){
-        @cols = @{$cfg_fields};
+    }
+    if($cfg_fields) {
+        @cols = split(',', $cfg_fields);
     }
     
-    if(my $c = $cfg_display){
-        @cols = @$c;
+    if($cfg_display) {
+        @cols = split(',', $cfg_display);
     }
 
     my $table = HTML::Table->new(
