@@ -1,5 +1,8 @@
 package CIF::Client::Plugin::Iodef::Malware;
 
+use warnings;
+use strict;
+
 sub hash_simple {
     my $class = shift;
     my $hash = shift;
@@ -23,7 +26,7 @@ sub hash_simple {
             $sha1   = $a->{'content'} if(/sha1/);
         }
     }
-    if($impact eq 'malware'){
+    if($impact eq 'malware' || $impact eq 'search'){
         return({
             md5 => $md5,
             sha1    => $sha1
